# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

<!-- changelog-start -->

## [Unreleased]

## [0.1.0] - 2025-09-06

We are pleased to announce the release of litestar-playwright [0.1.0].

### :rocket: Features

- feat(implementation): refactor project structure, rename to litestar_playwright, and implement the core functionality by @hasansezertasan in (#2)

### :construction_worker: Continuous Integration

- refactor(documentation-and-cicd): improve documentation and cicd by @hasansezertasan in (#4)
- feat(implementation): refactor project structure, rename to litestar_playwright, and implement the core functionality by @hasansezertasan in (#2)

### :memo: Documentation

- refactor(documentation-and-cicd): improve documentation and cicd by @hasansezertasan in (#4)
- feat(implementation): refactor project structure, rename to litestar_playwright, and implement the core functionality by @hasansezertasan in (#2)

### :bow: Credits

Special thanks to the following contributors who helped with this release: @hasansezertasan

**Full Changelog**: https://github.com/hasansezertasan/litestar-playwright/compare/...0.1.0

<!-- refs -->

[unreleased]: https://github.com/hasansezertasan/litestar-playwright/compare/0.1.0...HEAD
[0.1.0]: https://github.com/hasansezertasan/litestar-playwright/releases/tag/0.1.0

<!-- changelog-end -->
